package model

import "gorm.io/plugin/soft_delete"

type CostLog struct {
	Uuid          string `gorm:"column:uuid;type:varchar(50);NOT NULL;primary_key;" json:"id"`
	ArtistUuid    string `gorm:"column:artist_uuid;type:varchar(50);NOT NULL;index:idx_artist_uuid;default:'';comment:艺人ID" json:"artistUuid"`
	ArtistName    string `gorm:"column:artist_name;type:varchar(50);NOT NULL;default:'';comment:艺人名称" json:"artistName"`
	ArtistPhone   string `gorm:"column:artist_phone;type:varchar(50);NOT NULL;default:'';comment:艺人手机号" json:"artistPhone"`
	WorkUuid      string `gorm:"column:work_uuid;type:varchar(50);NOT NULL;index:idx_work_uuid;default:'';comment:作品uuid" json:"workUuid"`
	WorkCategory  uint8  `gorm:"column:work_category;type:tinyint(1);NOT NULL;default:1;comment: 1 图文 2 视频" json:"workCategory"`
	BundleUuid    string `gorm:"column:bundle_uuid;type:varchar(50);NOT NULL;index:idx_bundle_uuid;default:'';comment:套餐ID uuid" json:"bundleUuid"`
	BundleName    string `gorm:"column:bundle_name;type:varchar(50);NOT NULL;default:'';comment:套餐名称" json:"bundleName"`
	PlatformIDs   string `gorm:"column:platform_ids;type:json;NOT NULL;comment:发布平台ID集合" json:"platformIDs"`
	MediaNames    string `gorm:"column:media_names;type:varchar(600);NOT NULL;default:'';comment:自媒体账号名称集合" json:"mediaNames"`
	MediaAccIDs   string `gorm:"column:media_acc_ids;type:varchar(600);NOT NULL;default:'';comment:自媒体账号ID集合" json:"mediaAccIDs"`
	WorkTitle     string `gorm:"column:work_title;type:varchar(50);NOT NULL;" json:"workTitle"`
	SubmitTime    string `gorm:"column:submit_time;type:varchar(50);NOT NULL;default:'';comment:提交时间" json:"submitTime"`
	OperatorName  string `gorm:"column:operator_name;type:varchar(50);NOT NULL;default:'';comment:操作人名称" json:"operatorName"`
	OperatorID    string `gorm:"column:operator_id;type:varchar(50);NOT NULL;default:'';comment:操作人ID" json:"operatorID"`
	OperatorPhone string `gorm:"column:operator_phone;type:varchar(50);NOT NULL;default:'';comment:操作人手机号" json:"operatorPhone"`
	Status        uint8  `gorm:"column:status;type:tinyint(1);NOT NULL;default:1;comment: 1 有效 2 失效" json:"status"`
	CreatedAt     int    `gorm:"column:created_at;type:int(11);autoCreateTime" json:"createdAt"`
	UpdatedAt     int    `gorm:"column:updated_at;type:int(11);autoCreateTime" json:"updatedAt"`
	DeletedAt     soft_delete.DeletedAt
}

func (CostLog) TableName() string {
	return "cast_cost_log"
}

type CastWorkImage struct {
	Uuid      string `json:"uuid" gorm:"uuid"`
	WorkUuid  string `json:"work_uuid" gorm:"work_uuid"`   // 作品uuid
	ImageUrls string `json:"image_urls" gorm:"image_urls"` // 图片url集合
	CreatedAt int64  `json:"created_at" gorm:"created_at"`
	UpdatedAt int64  `json:"updated_at" gorm:"updated_at"`
	DeletedAt int64  `json:"deleted_at" gorm:"deleted_at"`
}

// TableName 表名称
func (*CastWorkImage) TableName() string {
	return "cast_work_image"
}

type CastWorkVideo struct {
	Uuid      string `json:"uuid" gorm:"uuid"`
	WorkUuid  string `json:"work_uuid" gorm:"work_uuid"` // 作品uuid
	CoverUrl  string `json:"cover_url" gorm:"cover_url"` // 封面url
	VideoUrl  string `json:"video_url" gorm:"video_url"` // 视频url
	CreatedAt int64  `json:"created_at" gorm:"created_at"`
	UpdatedAt int64  `json:"updated_at" gorm:"updated_at"`
	DeletedAt int64  `json:"deleted_at" gorm:"deleted_at"`
}

// TableName 表名称
func (*CastWorkVideo) TableName() string {
	return "cast_work_video"
}
